#!/usr/bin/env bash

[[ ${BURR_GIT_LOADED:-} -eq 1 ]] && return

# including the local config variables
if [ -f "${project_base}/config/env/local/localdev.cfg" ]; then
    source "${project_base}/config/env/local/localdev.cfg"
else
    echo "1. No local config file found at ${project_base}/config/env/local/localdev.cfg"
fi

git_initialise_with_remote_repo() {
    # @TODO Validate ${git_clone_base_location}" and "${main_repo_name} to ensure wildcards like * are not used.
    #git clone --recursive git@bitbucket.org:brewpixel/roastery.git "${git_clone_base_location}"/"${main_repo_name}" && rm -rf "${git_clone_base_location}"/"${main_repo_name}"/.git
    #cd "${git_clone_base_location}"/"${main_repo_name}"
    cd "${1}"
    echo "${1}"
    if [ -d .git ]; then
        cd "${1}" && rm -rf .git
    fi
    git init
    # We should check for fatal: remote origin already exists and if so then use git remote set-url origin
    origin_exists=$(git remote -v | grep -c 'origin')
    if [ ${origin_exists} -eq 0 ]; then
        git remote add origin ${2}
    else
        git remote set-url origin ${2}
    fi
    git add .
    git commit -m 'Initial commit'

    git push -u origin --all
    git push origin --tags
}

git_clone_repo() {
    cd "${1}"
    echo "${1}"
    git clone "$2" "$3"
    cd "${1}/${3}"
    echo "${1}/${3}"
    if [ -d .git ]; then
        cd "${1}/${3}" && rm -rf .git
    fi
}

# checks if branch has something pending
parse_git_dirty_string() {
	string=${1-*}
  	git diff --quiet --ignore-submodules HEAD 2>/dev/null; [ $? -eq 1 ] && echo ${string}
}

# 1 is true that it is dirty and 0 is false.
parse_git_is_dirty() {
	git diff --quiet --ignore-submodules HEAD 2>/dev/null; echo $?
}

# gets the current git branch
parse_git_branch() {
  git branch --no-color 2> /dev/null | sed -e '/^[^*]/d' -e "s/* \(.*\)/\1$(parse_git_dirty_string)/"
}

# get last commit hash prepended with @ (i.e. @8a323d0)
parse_git_hash() {
  git rev-parse --short HEAD 2> /dev/null | sed "s/\(.*\)/@\1/"
}

# DEMO
#GIT_BRANCH=$(parse_git_branch)$(parse_git_hash)
#echo ${GIT_BRANCH}
#
#@TODO:Clone a git repo if it does not exist, or pull into it if it does exist
#REPOSRC=$1
#LOCALREPO=$2

# We do it this way so that we can abstract if from just git later on
#LOCALREPO_VC_DIR=$LOCALREPO/.git

#if [ ! -d "$LOCALREPO_VC_DIR" ]
#then
#    git clone "$REPOSRC" "$LOCALREPO"
#else
#    cd "$LOCALREPO"
#    git pull "$REPOSRC"
#fi

BURR_GIT_LOADED=1
